@@ -92,6 +92,7 @@ class FacetedSearchMixin(SearchMixin):
 
     form_class = FacetedSearchForm
     facet_fields = None
+    date_facet_fields = None
 
     def get_form_kwargs(self):
         kwargs = super().get_form_kwargs()
@@ -107,6 +108,11 @@ class FacetedSearchMixin(SearchMixin):
         qs = super().get_queryset()
         for field in self.facet_fields:
             qs = qs.facet(field)
+
+        if self.date_facet_fields:
+            for field in self.date_facet_fields:
+                qs = qs.date_facet(**field)
+
         return qs
 
 
