@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django.test import TestCase
 
 from haystack import connections, inputs
@@ -6,7 +5,7 @@ from haystack import connections, inputs
 
 class Elasticsearch2InputTestCase(TestCase):
     def setUp(self):
-        super(Elasticsearch2InputTestCase, self).setUp()
+        super().setUp()
         self.query_obj = connections["elasticsearch"].get_query()
 
     def test_raw_init(self):
