@@ -344,7 +344,7 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel1",
                     "name_exact": "daniel1",
-                    "text": "Indexed!\n1",
+                    "text": "Indexed!\n1\n",
                     "pub_date": "2009-02-24T00:00:00",
                     "id": "core.mockmodel.1",
                 },
@@ -353,7 +353,7 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel2",
                     "name_exact": "daniel2",
-                    "text": "Indexed!\n2",
+                    "text": "Indexed!\n2\n",
                     "pub_date": "2009-02-23T00:00:00",
                     "id": "core.mockmodel.2",
                 },
@@ -362,7 +362,7 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel3",
                     "name_exact": "daniel3",
-                    "text": "Indexed!\n3",
+                    "text": "Indexed!\n3\n",
                     "pub_date": "2009-02-22T00:00:00",
                     "id": "core.mockmodel.3",
                 },
@@ -397,7 +397,7 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel2",
                     "name_exact": "daniel2",
-                    "text": "Indexed!\n2",
+                    "text": "Indexed!\n2\n",
                     "pub_date": "2009-02-23T00:00:00",
                     "id": "core.mockmodel.2",
                 },
@@ -406,7 +406,7 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel3",
                     "name_exact": "daniel3",
-                    "text": "Indexed!\n3",
+                    "text": "Indexed!\n3\n",
                     "pub_date": "2009-02-22T00:00:00",
                     "id": "core.mockmodel.3",
                 },
@@ -480,7 +480,11 @@ class Elasticsearch7SearchBackendTestCase(TestCase):
                     for result in self.sb.search("Index", highlight=True)["results"]
                 ]
             ),
-            ["<em>Indexed</em>!\n1", "<em>Indexed</em>!\n2", "<em>Indexed</em>!\n3"],
+            [
+                "<em>Indexed</em>!\n1",
+                "<em>Indexed</em>!\n2",
+                "<em>Indexed</em>!\n3",
+            ],
         )
 
         self.assertEqual(self.sb.search("Indx")["hits"], 0)
