@@ -360,7 +360,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel1",
                     "name_exact": "daniel1",
-                    "text": "Indexed!\n1",
+                    "text": "Indexed!\n1\n",
                     "pub_date": "2009-02-24T00:00:00",
                     "id": "core.mockmodel.1",
                 },
@@ -369,7 +369,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel2",
                     "name_exact": "daniel2",
-                    "text": "Indexed!\n2",
+                    "text": "Indexed!\n2\n",
                     "pub_date": "2009-02-23T00:00:00",
                     "id": "core.mockmodel.2",
                 },
@@ -378,7 +378,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel3",
                     "name_exact": "daniel3",
-                    "text": "Indexed!\n3",
+                    "text": "Indexed!\n3\n",
                     "pub_date": "2009-02-22T00:00:00",
                     "id": "core.mockmodel.3",
                 },
@@ -413,7 +413,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel2",
                     "name_exact": "daniel2",
-                    "text": "Indexed!\n2",
+                    "text": "Indexed!\n2\n",
                     "pub_date": "2009-02-23T00:00:00",
                     "id": "core.mockmodel.2",
                 },
@@ -422,7 +422,7 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     "django_ct": "core.mockmodel",
                     "name": "daniel3",
                     "name_exact": "daniel3",
-                    "text": "Indexed!\n3",
+                    "text": "Indexed!\n3\n",
                     "pub_date": "2009-02-22T00:00:00",
                     "id": "core.mockmodel.3",
                 },
@@ -482,7 +482,11 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                     for result in self.sb.search("Index", highlight=True)["results"]
                 ]
             ),
-            ["<em>Indexed</em>!\n1", "<em>Indexed</em>!\n2", "<em>Indexed</em>!\n3"],
+            [
+                "<em>Indexed</em>!\n1\n",
+                "<em>Indexed</em>!\n2\n",
+                "<em>Indexed</em>!\n3\n",
+            ],
         )
         self.assertEqual(
             sorted(
@@ -495,9 +499,9 @@ class ElasticsearchSearchBackendTestCase(TestCase):
                 ]
             ),
             [
-                "<start>Indexed</end>!\n1",
-                "<start>Indexed</end>!\n2",
-                "<start>Indexed</end>!\n3",
+                "<start>Indexed</end>!\n1\n",
+                "<start>Indexed</end>!\n2\n",
+                "<start>Indexed</end>!\n3\n",
             ],
         )
 
@@ -958,13 +962,13 @@ class LiveElasticsearchSearchQuerySetTestCase(TestCase):
     def test_highlight(self):
         reset_search_queries()
         results = self.sqs.filter(content="index").highlight()
-        self.assertEqual(results[0].highlighted, ["<em>Indexed</em>!\n1"])
+        self.assertEqual(results[0].highlighted, ["<em>Indexed</em>!\n1\n"])
 
     def test_highlight_options(self):
         reset_search_queries()
         results = self.sqs.filter(content="index")
         results = results.highlight(pre_tags=["<i>"], post_tags=["</i>"])
-        self.assertEqual(results[0].highlighted, ["<i>Indexed</i>!\n1"])
+        self.assertEqual(results[0].highlighted, ["<i>Indexed</i>!\n1\n"])
 
     def test_manual_iter(self):
         results = self.sqs.all()
