@@ -1,5 +1,4 @@
-# encoding: utf-8
-from django.conf.urls import url
+from django.urls import path
 
 from haystack.views import SearchView
 
@@ -9,9 +8,9 @@ class CustomPerPage(SearchView):
 
 
 urlpatterns = [
-    url(r"^search/$", CustomPerPage(load_all=False), name="haystack_search"),
-    url(
-        r"^search2/$",
+    path("search/", CustomPerPage(load_all=False), name="haystack_search"),
+    path(
+        "search2/",
         CustomPerPage(load_all=False, results_per_page=2),
         name="haystack_search",
     ),
